module Config.Pages.Debate.Arguments.Records.HealthyChocolate exposing (..)

import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (..)


argumentHealthyChocolate : Argument
argumentHealthyChocolate =
    { argumentTitle = toTitleCase "Argument for Healthy Chocolate"
    , propositionTitle = "Chocolate does not cause atherosclerosis."
    , propositionReductio = ""
    , propositionSummary = "Despite chocolate containing high amounts of saturated fat, populations that consume more chocolate do not exhibit higher rates of atherosclerosis, suggesting that chocolate does not have the same effect on heart disease risk as most other saturated fat sources."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~5Qx)),(~3Qc)|=(~3Pc)"
    , argumentCertainty = 7
    , argumentImage = "chocolate"
    , argumentHashtags = []
   
    
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controlling for relevant variables."
          }
        , { definiendum = "Q(x)"
          , definiens = "there is a dearth of epistemically countervailing data on (x)."
          }
        , { definiendum = "R(x)"
          , definiens = "it is more reasonable to believe that (x) is  healthy than it is to believe the opposite."
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "c"
          , definiens = "chocolate"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a food has a strong tendency to associate with a reduced risk of morbidity and/or mortality after adjusting and/or controling for relevant variables and there is a dearth of epistemically countervailing data on that food, then it is more reasonable to believe that the food is healthy than it is to believe the opposite."
                  , notation = "∀x((Px∧Qx)→Rx)"
                  }
                , { premise = "Chocolate has a strong tendency to associate with a reduced risk of morbidity and mortality after adjustment and/or controlling for relevant variables."
                  , notation = "Pc"
                  }
                , { premise = "There is a dearth of epistemically countervailing data on chocolate."
                  , notation = "Qc"
                  }
                ]
          , conclusion = "Therefore, it is more reasonable to believe that chocolate is healthy than it is to believe the opposite."
          , conclusionNotation = "Rc"
          }
        ]
    }
