module Config.Pages.Services.Records.ElmBuilds exposing (..)

import Config.Helpers.Converters exposing (formatName)
import Config.Pages.Services.Types exposing (..)
import Config.Style.Colour exposing (colourTheme)
import Config.Style.Transitions exposing (hoverFontDarkOrange, transitionStyleMedium)
import Element as E exposing (..)
import Element.Font as F exposing (..)
import Route.Path as Path


servicesElmBuilds : Service msg
servicesElmBuilds =
    let
        name : String
        name =
            "Front End Development"
    in
    { serviceImage = formatName name
    , serviceLink = Path.toString Path.Services_Elm
    , serviceName = name
    , serviceRate = "$20/hr"
    , isNewTabLink = False
    , serviceDescription =
        [ { point = "Receive a custom website frontend written in Elm." }
        , { point = "Tailored solutions based on user needs." }
        , { point = "Help with integration and server integration." }
        , { point = "Receive unlimited revisions before finalization." }
        ]
    , serviceArticle =
        { articleTitles =
            { title1 = "What You Get"
            , title2 = "Requirements"
            , title3 = "Example"
            , title4 = ""
            , title5 = ""
            , title6 = ""
            , title7 = ""
            , title8 = ""
            , title9 = ""
            , title10 = ""
            }
        , articleParagraph =
            { paragraph1 = [ text "The site that you're currently viewing this on was written by me in the Elm programming language. In the process of programming this website, I realized that I could create reasonably high quality work with Elm, so I'm offering it as a service at a fee that reflects my skill level. ", text "If you're in the market for a new frontend for your website, please inquire at ", el [ F.bold, F.color colourTheme.textLightOrange ] <| text "nick@upRootNutrition.com", text "." ]
            , paragraph2 = [text "Below is an example of a function that I wrote for this site. This particular function renders all of the circular images on all of the site's information cards. Any time you see one of those images, this function is responsible for it."]
            , paragraph3 =
                [ text "The source code for this website is viewable on "
                , newTabLink []
                    { url = "https://gitlab.com/upRootNutrition/website"
                    , label =
                        el
                            [ F.color colourTheme.textLightOrange
                            , hoverFontDarkOrange
                            , transitionStyleMedium
                            ]
                        <|
                            text "Gitlab"
                    }
                ]
            , paragraph4 = []
            }
        , articleListEntries =
            { list1 =
                [ "An Elm-based website written to your specifications."
                , "Two revisions to better meet your needs and vision."
                , "Six months of free support to correct mistakes."
                ]
            , list2 =
                [ "A clear vision of what you want your site to look like."
                , "A clear description of your site's pages and structure."
                , "Any bespoke frontend functionality you want included."
                ]
            , list3 =
                []
            , list4 =
                []
            , list5 =
                []
            , list6 =
                []
            , list7 =
                []
            , list8 =
                []
            , list9 =
                []
            , list10 =
                []
            }
        }
    }
